@@ -19,7 +19,9 @@
    include_once('../src/validate.php');
    include_once('../functions/page_header.php');
    include_once('../functions/display_messages.php');
+   include_once('../functions/imap.php');
    include_once('../functions/addressbook.php');
+   include_once('../functions/array.php');
    include_once('../src/load_prefs.php');
 
    // Set up the page
@@ -35,12 +37,10 @@
     </tr>
   </table>
 <?php
-   global $username, $data_dir, $_POST, $_FILES;
+   global $username, $data_dir, $_POST;
 
    // Deal with the submitted form
-   if ($_POST['submit_ldifimport'] && 
-       is_uploaded_file($_FILES['fname']['tmp_name']) &&
-       is_readable($_FILES['fname']['tmp_name'])) {
+   if ($_POST['submit_ldifimport']) {
 ?>
   <TABLE cols="5" border="1" width="95%">
     <TR>
@@ -51,45 +51,38 @@
       <TH width=30%>Comment</TH>
     </TR>
 <?php
+      // Open the imported file for read
+      $file = fopen($HTTP_POST_FILES['fname']['tmp_name'], 'r');
 
       // Open the address book
       $abook = addressbook_init(true, true);
       $n = 0;
       $addaddr = array();
 
-      // Open the imported file for read
-      $file = file($_FILES['fname']['tmp_name']);
-
-      // As per rfc2849, an end of line may be CR, LF or both CR and LF
-      // the "file" command above will only break the file on newlines
-      // so we must break it on carriage returns ourselves
-      for ($l=0; $l < count($file); $l++) {
-	 $line = explode("\r", rtrim($file[$l]));
-         array_splice($file, $l, 1, $line);
-      }
-
       // Process the file
-      for ($l=0; $l < count($file); $l++) {
-         // If the next line begins with a space, then this line
-         // is folded (as per rfc2849)
-         while (ereg("^ ", $file[$l+1])) {
-            // unfold this line by sticking the next line on the end
-            $file[$l] .= substr($file[$l+1], 1);
-
-            // remove the next line from the array
-            array_splice($file, $l+1, 1);
-         }
-
-         // feed this line to the processor, which returns true when it has
-         // completed an entry (which may be any number of lines).
-         if (ProcessLine($file[$l], $addaddr, $n, $abook)) {
-            // clear the decks for the next entry
-            unset($addaddr);
+      while ( !feof ($file)) {
+         // fetch a line
+         $line = fgets($file, 1024);
+         // trim it
+	 $line = trim($line);
+         // break it on carriage returns
+	 $line = explode("\r", $line);
+	 foreach ($line as $l) {
+            // feed it to the processor, which returns true when it has
+            // completed an entry (which may be an indeterminate number
+            // of lines.
+  	    if (ProcessLine($l, $addaddr, $n, $abook)) {
+               // clear the decks for the next entry
+               unset($addaddr);
+            }
          }
       }
-      // flush the processor in case there is no blank line at the end
+      // process any leftovers (in case there is no blank line at the end)
       ProcessLine('', $addaddr, $n, $abook);
 
+      // Get rid of the file
+      fclose($file);
+
       echo "  </TABLE>\n";
       echo "  <center> Address book imported ".$n." records </center>\n";
    }
